-- name: ListCampuses :many
SELECT * FROM campus;

-- name: ListStudents :many
SELECT * FROM students;

-- name: ListMetadata :many
SELECT * FROM product_meta;

-- name: ListCalories :many
SELECT * FROM calories;

-- name: GetProductMetadata :many
SELECT * FROM product_metadata;